.. _community:

=========
Community
=========

Schematics was created in Brooklyn, NY by `James Dennis <http://j2labs.io>`_.
Since then, the code has been worked on by folks from around the world.  If you
have ideas, we encourage you to share them!

Special thanks to `Hacker School <http://hackerschool.com>`_, `Plain Vanilla
<http://www.plainvanilla.is/>`_, `Quantopian <http://quantopian.com>`_, `Apple
<http://apple.com>`_, `Johns Hopkins University <http://jhu.edu>`_, and
everyone who has contributed to Schematics.


Bugs & Features
===============

We track bugs, feature requests, and documentation requests with `Github Issues
<https://github.com/schematics/schematics/issues>`_.


Mailing list
============

We discuss the future of Schematics and upcoming changes in detail on
`schematics-dev <http://groups.google.com/group/schematics-dev>`_.

If you've read the documentation and still haven't found the answer you're
looking for, you should reach out to us here too.


Contributing
============

If you're interested in contributing code or documentation to Schematics,
please visit the :doc:`development` for instructions.
